// Copyright (C) 2021 (Lilly Rosaline) <lilly.rosaline@waterlilly.dev>
// This file is part of GayPK.
//
// GayPK is non-violent software: you can use, redistribute,
// and/or modify it under the terms of the CNPLv7+ as found
// in the LICENSE file in the source code root directory or
// at <https://git.pixie.town/thufie/npl-builder>.
//
// GayPK comes with ABSOLUTELY NO WARRANTY, to the extent
// permitted by applicable law.  See LICENSE.md for details.

use std::collections::{BTreeMap, HashMap};

/// Get the list of packages to do a certain action on from the command line arguments. Returns a map of the package name as well as if the package is remote or an archive (.gaypk file).
pub fn get_package_install_list(args: Vec<String>) -> BTreeMap<String, bool>{
    let mut archive = false; // Indicates if the current package is an archive or a remote package.
    let mut packages: BTreeMap<String, bool> = BTreeMap::new(); // The list of all packages, including their archive status.
    for arg in args {
        match arg.as_str() {
            "-r" | "--remote" => { // The remote flag means that all packages following are remote.
                archive = false;
            }
            "-a" | "--archive"=> { // The archive flag means that all packages following are archives.
                archive = true;
            }
            _ => {
                if !arg.starts_with("-") { // Make sure there aren't any other flags (TODO implement config flags)
                    packages.insert(arg, archive); // Insert a package along with the current state of archive.
                } else {
                    panic!("Unknown flag '{arg}'");
                }
            }
        }
    }
    packages
}